<!-- warning: Please don't edit this file. It was automatically generated. -->

# winrt-Windows.ApplicationModel.Payments.Provider

Windows Runtime (WinRT) APIs for for the `Windows.ApplicationModel.Payments.Provider` namespace.

This package provides the `winrt.windows.applicationmodel.payments.provider` module.
